@@ -11,14 +11,11 @@ use strict;
 use warnings;
 
 package File::Spec::Native;
-BEGIN {
-  $File::Spec::Native::VERSION = '1.003';
-}
-BEGIN {
-  $File::Spec::Native::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Use native OS implementation of File::Spec from a subclass
+# git description: v1.003-8-gd52fa9e
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Use native OS implementation of File::Spec from a subclass
+$File::Spec::Native::VERSION = '1.004';
 use File::Spec (); #core
 our @ISA = qw(File::Spec);
 
@@ -26,12 +23,14 @@ our @ISA = qw(File::Spec);
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Randy Stauner cpan testmatrix url annocpan anno bugtracker rt cpants
-kwalitee diff irc mailto metadata placeholders
+=encoding UTF-8
+
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS cpan testmatrix url annocpan anno bugtracker
+rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -39,7 +38,7 @@ File::Spec::Native - Use native OS implementation of File::Spec from a subclass
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -111,66 +110,26 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/File-Spec-Native>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Spec-Native>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Spec-Native>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/F/File-Spec-Native>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=File-Spec-Native>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=File::Spec::Native>
+L<http://metacpan.org/release/File-Spec-Native>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-file-spec-native at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Spec-Native>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=File-Spec-Native>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
 
 
-L<http://github.com/rwstauner/File-Spec-Native>
+L<https://github.com/rwstauner/File-Spec-Native>
 
-  git clone http://github.com/rwstauner/File-Spec-Native
+  git clone https://github.com/rwstauner/File-Spec-Native.git
 
 =head1 AUTHOR
 
@@ -184,4 +143,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
